@@ -430,6 +430,12 @@ class CLIWrapperBase:
         cluster_ops.set(args.cluster_id, args.attr_name, args.attr_value)
         return True
 
+    def cluster__change_name(self, sub_command, args):
+        cluster_id = args.cluster_id
+        cluster_name = args.name
+        cluster_ops.change_cluster_name(cluster_id, cluster_name)
+        return True
+
     def cluster__complete_expand(self, sub_command, args):
         cluster_ops.cluster_expand(args.cluster_id)
         return True
@@ -458,7 +464,8 @@ class CLIWrapperBase:
             crypto_key1=args.crypto_key1,
             crypto_key2=args.crypto_key2,
             lvol_priority_class=lvol_priority_class,
-            uid=args.uid, pvc_name=args.pvc_name, namespace=args.namespace)
+            uid=args.uid, pvc_name=args.pvc_name, namespace=args.namespace, 
+            max_namespace_per_subsys=args.max_namespace_per_subsys)
         if results:
             return results
         else:
@@ -544,7 +551,9 @@ class CLIWrapperBase:
         cluster_ip = args.cluster_ip
         cluster_secret = args.cluster_secret
         ifname = args.ifname
-        return mgmt_ops.deploy_mgmt_node(cluster_ip, cluster_id, ifname, cluster_secret)
+        mgmt_ip = args.mgmt_ip
+        mode = args.mode
+        return mgmt_ops.deploy_mgmt_node(cluster_ip, cluster_id, ifname, mgmt_ip, cluster_secret, mode)
 
     def control_plane__list(self, sub_command, args):
         return mgmt_ops.list_mgmt_nodes(args.json)
@@ -593,12 +602,6 @@ class CLIWrapperBase:
     def storage_pool__disable(self, sub_command, args):
         return pool_controller.set_status(args.pool_id, Pool.STATUS_INACTIVE)
 
-    def storage_pool__get_secret(self, sub_command, args):
-        return pool_controller.get_secret(args.pool_id)
-
-    def storage_pool__update_secret(self, sub_command, args):
-        return pool_controller.set_secret(args.pool_id, args.secret)
-
     def storage_pool__get_capacity(self, sub_command, args):
         return pool_controller.get_capacity(args.pool_id)
 
@@ -639,6 +642,7 @@ class CLIWrapperBase:
         distr_bs = args.distr_bs
         distr_chunk_bs = args.distr_chunk_bs
         ha_type = args.ha_type
+        name = args.name
 
         enable_node_affinity = args.enable_node_affinity
         qpair_count = args.qpair_count
@@ -650,7 +654,7 @@ class CLIWrapperBase:
         return cluster_ops.add_cluster(
             blk_size, page_size_in_blocks, cap_warn, cap_crit, prov_cap_warn, prov_cap_crit,
             distr_ndcs, distr_npcs, distr_bs, distr_chunk_bs, ha_type, enable_node_affinity,
-            qpair_count, max_queue_size, inflight_io_threshold, enable_qos, strict_node_anti_affinity)
+            qpair_count, max_queue_size, inflight_io_threshold, enable_qos, strict_node_anti_affinity, name)
 
     def cluster_create(self, args):
         page_size_in_blocks = args.page_size
@@ -661,11 +665,13 @@ class CLIWrapperBase:
         prov_cap_warn = args.prov_cap_warn
         prov_cap_crit = args.prov_cap_crit
         ifname = args.ifname
+        mgmt_ip = args.mgmt_ip
         distr_ndcs = args.distr_ndcs
         distr_npcs = args.distr_npcs
         distr_bs = args.distr_bs
         distr_chunk_bs = args.distr_chunk_bs
         ha_type = args.ha_type
+        mode = args.mode
         log_del_interval = args.log_del_interval
         metrics_retention_period = args.metrics_retention_period
         contact_point = args.contact_point
@@ -677,13 +683,17 @@ class CLIWrapperBase:
         enable_qos = args.enable_qos
         disable_monitoring = args.disable_monitoring
         strict_node_anti_affinity = args.strict_node_anti_affinity
+        name = args.name
+        tls_secret = args.tls_secret
+        ingress_host_source = args.ingress_host_source
+        dns_name = args.dns_name
 
         return cluster_ops.create_cluster(
             blk_size, page_size_in_blocks,
             CLI_PASS, cap_warn, cap_crit, prov_cap_warn, prov_cap_crit,
-            ifname, log_del_interval, metrics_retention_period, contact_point, grafana_endpoint,
-            distr_ndcs, distr_npcs, distr_bs, distr_chunk_bs, ha_type, enable_node_affinity,
-            qpair_count, max_queue_size, inflight_io_threshold, enable_qos, disable_monitoring, strict_node_anti_affinity)
+            ifname, mgmt_ip, log_del_interval, metrics_retention_period, contact_point, grafana_endpoint,
+            distr_ndcs, distr_npcs, distr_bs, distr_chunk_bs, ha_type, mode, enable_node_affinity,
+            qpair_count, max_queue_size, inflight_io_threshold, enable_qos, disable_monitoring, strict_node_anti_affinity, name, tls_secret, ingress_host_source, dns_name)
 
     def query_yes_no(self, question, default="yes"):
         """Ask a yes/no question via raw_input() and return their answer.
