@@ -96,7 +96,8 @@ def add_device_to_auto_restart(device):
 
 def add_node_to_auto_restart(node):
     cluster = db.get_cluster_by_id(node.cluster_id)
-    if cluster.status not in [Cluster.STATUS_ACTIVE, Cluster.STATUS_DEGRADED, Cluster.STATUS_READONLY]:
+    if cluster.status not in [Cluster.STATUS_ACTIVE, Cluster.STATUS_DEGRADED,
+                              Cluster.STATUS_READONLY, Cluster.STATUS_UNREADY]:
         logger.warning(f"Cluster is not active, skip node auto restart, status: {cluster.status}")
         return False
     for sn in db.get_storage_nodes_by_cluster_id(node.cluster_id):
@@ -148,9 +149,10 @@ def list_tasks(cluster_id, is_json=False, limit=50, **kwargs):
 
 
 def cancel_task(task_id):
-    task = db.get_task_by_id(task_id)
-    if not task:
-        logger.error("Task not found: %s", task_id)
+    try:
+        task = db.get_task_by_id(task_id)
+    except KeyError as e:
+        logger.error(e)
         return False
 
     if task.device_id:
