@@ -1,6 +1,11 @@
 import json
+from json import JSONDecodeError
+from typing import Any, Optional
 
 import requests
+from requests.exceptions import ConnectionError, HTTPError, Timeout, TooManyRedirects
+import jsonschema
+from jsonschema.exceptions import ValidationError
 
 from simplyblock_core import constants, utils
 from requests.adapters import HTTPAdapter
@@ -9,17 +14,71 @@ from urllib3 import Retry
 logger = utils.get_logger()
 
 
-def print_dict(d):
-    print(json.dumps(d, indent=2))
-
-
-def print_json(s):
-    print(json.dumps(s, indent=2).strip('"'))
+_response_schema = {
+    "$schema": "http://json-schema.org/draft-07/schema#",
+    "title": "JSON-RPC 2.0 Response",
+    "description": "A JSON-RPC 2.0 response object",
+    "type": "object",
+    "required": ["jsonrpc"],
+    "properties": {
+        "jsonrpc": {
+            "type": "string",
+            "enum": ["2.0"],
+            "description": "JSON-RPC version string",
+        },
+        "result": {
+            "description": "The result of the RPC call if successful",
+        },
+        "error": {
+            "description": "Error information if an error occurred",
+            "$ref": "#/definitions/error",
+        },
+        "id": {
+            "description": "Identifier matching the request",
+            "oneOf": [
+                { "type": "string" },
+                { "type": "number" },
+                { "type": "null" },
+            ],
+        },
+    },
+    "oneOf": [
+        { "required": ["result", "id"] },
+        { "required": ["error", "id"] },
+    ],
+    "additionalProperties": False,
+    "definitions": {
+        "error": {
+            "type": "object",
+            "required": ["code", "message"],
+            "properties": {
+                "code": {
+                    "type": "integer",
+                    "description": "Error code",
+                },
+                "message": {
+                    "type": "string",
+                    "description": "Error message",
+                },
+                "data": {
+                    "description": "Additional error information",
+                },
+            },
+            "additionalProperties": False
+        },
+    },
+}
 
 
 class RPCException(Exception):
-    def __init__(self, message):
+    def __init__(self, message: str, code: Optional[int] = None, data: Any = None):
+        super().__init__(message, code, data)
+        self.code = code
         self.message = message
+        self.data = data
+
+
+_response_validator = jsonschema.validators.validator_for(_response_schema)(_response_schema)  # type: ignore[call-arg]
 
 
 class RPCClient:
@@ -40,7 +99,6 @@ class RPCClient:
         retries = Retry(total=retry, backoff_factor=1, connect=retry, read=retry,
                         allowed_methods=self.DEFAULT_ALLOWED_METHODS)
         self.session.mount("http://", HTTPAdapter(max_retries=retries))
-        self.session.timeout = self.timeout
 
     def _request(self, method, params=None):
         ret, _ = self._request2(method, params)
@@ -86,6 +144,30 @@ class RPCClient:
 
         return None, None
 
+    def _request3(self, method: str, **kwargs):
+        logger.debug("Requesting method: %s, params: %s", method, kwargs)
+        try:
+            response = self.session.post(self.url, data=json.dumps({
+                'id': 1,
+                'method': method,
+                'params': kwargs,
+            }), timeout=self.timeout)
+            response.raise_for_status()
+            data = response.json()
+            _response_validator.validate(data)
+        except (
+                ConnectionError, Timeout, TooManyRedirects, HTTPError,  # requests
+                JSONDecodeError,  # json
+                ValidationError,  # jsonschema
+        ) as e:
+            raise RPCException('Request failed') from e
+
+        if (error := data.get('error')) is not None:
+            raise RPCException(**error)
+
+        return data['result']
+
+
     def get_version(self):
         return self._request("spdk_get_version")
 
@@ -199,8 +281,12 @@ class RPCClient:
         return self._request("bdev_nvme_get_controllers", params)
 
     def bdev_nvme_controller_attach(self, name, pci_addr):
-        params = {"name": name, "trtype": "pcie", "traddr": pci_addr}
-        return self._request2("bdev_nvme_attach_controller", params)
+        return self._request3(
+                "bdev_nvme_attach_controller", 
+                name=name,
+                trtype='pcie',
+                traddr=pci_addr,
+        )
 
     def alloc_bdev_controller_attach(self, name, pci_addr):
         params = {"traddr": pci_addr, "ns_id": 1, "label": name}
@@ -273,7 +359,7 @@ class RPCClient:
         params = {"name": device_name}
         return self._request("bdev_nvme_reset_controller", params)
 
-    def create_lvstore(self, name, bdev_name, cluster_sz, clear_method, num_md_pages_per_cluster_ratio):
+    def create_lvstore(self, name, bdev_name, cluster_sz, clear_method, num_md_pages_per_cluster_ratio=50):
         params = {
             "bdev_name": bdev_name,
             "lvs_name": name,
@@ -294,8 +380,9 @@ class RPCClient:
         }
         return self._request("bdev_lvol_create", params)
 
-    def delete_lvol(self, name):
-        params = {"name": name}
+    def delete_lvol(self, name, del_async=False):
+        params = {"name": name,
+                  "sync": del_async}
         return self._request("bdev_lvol_delete", params)
 
     def get_bdevs(self, name=None):
@@ -1019,11 +1106,7 @@ class RPCClient:
 
     def bdev_lvol_get_lvol_delete_status(self, name):
         """
-        Returns :-
-            0: lvol is deleted.
-            1: lvole deletion is in progress.
-            2: No delete action on lvol or the delete requets is queued or previous delete request
-               failed due to error.
+            https://docs.google.com/spreadsheets/d/1cQ1MkCRVRJUTXeO35erFaQc7CF0mV5t52jTIzZsARyY/edit?gid=0#gid=0
         """
         params = {
             "name": name
@@ -1080,3 +1163,25 @@ class RPCClient:
             "policy": policy,
         }
         return self._request("bdev_nvme_set_multipath_policy", params)
+
+    def jc_get_jm_status(self, jm_vuid):
+        """
+        Returns :-
+            { 'jm1': True, 'remote_jm2': True, 'remote_jm3': False}
+        If the state is False, it means JM is not ready, or it has an active replication task.
+        """
+        params = {
+            "jm_vuid": jm_vuid,
+        }
+        return self._request("jc_get_jm_status", params)
+
+    def bdev_distrib_check_inflight_io(self, jm_vuid):
+        """
+        output: boolean value
+            'True': It means we have in-flight IOs in the target distrib group
+            'False': there is no in-flight IO
+        """
+        params = {
+            "jm_vuid": jm_vuid,
+        }
+        return self._request("bdev_distrib_check_inflight_io", params)
