@@ -7,8 +7,10 @@ import traceback
 
 from flask import jsonify
 from pydantic import BaseModel, Field, model_validator
+from werkzeug.exceptions import HTTPException
 
 from simplyblock_core import constants
+from simplyblock_core.utils.pci import PCIAddress
 
 
 IP_PATTERN = re.compile(r'^\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}$')
@@ -94,11 +96,8 @@ def get_cluster_id(request):
 
 def get_aws_region():
     try:
-        from ec2_metadata import ec2_metadata
-        import requests
-        session = requests.session()
-        session.timeout = 3
-        data = ec2_metadata.EC2Metadata(session=session).instance_identity_document
+        import ec2_metadata
+        data = ec2_metadata.EC2Metadata().instance_identity_document
         return data["region"]
     except Exception:
         pass
@@ -107,7 +106,10 @@ def get_aws_region():
 
 
 def error_handler(exception: Exception):
-    """Return JSON instead of HTML for any exception."""
+    """Return JSON instead of HTML for any non-HTTP exception."""
+
+    if isinstance(exception, HTTPException):
+        return exception
 
     traceback.print_exception(type(exception), exception, exception.__traceback__)
 
@@ -118,7 +120,7 @@ def error_handler(exception: Exception):
             for frame
             in traceback.extract_tb(exception.__traceback__)
         ]
-    }, getattr(exception, 'code', 500)
+    }, 500
 
 
 class RPCPortParams(BaseModel):
@@ -126,7 +128,7 @@ class RPCPortParams(BaseModel):
 
 
 class DeviceParams(BaseModel):
-    device_pci: str
+    device_pci: PCIAddress
 
 
 class NVMEConnectParams(BaseModel):
